@@ -6,7 +6,7 @@ use Carp;
 use Argon::Client;
 
 use parent qw(Exporter);
-our @EXPORT = qw(connect process);
+our @EXPORT = qw(connect process task);
 
 my $CLIENT;
 
@@ -28,10 +28,14 @@ sub connect {
 }
 
 sub process (&@) {
-    my ($f, @args) = @_;
+    goto \&task;
+}
+
+sub task ($@) {
+    my ($task_class, @args) = @_;
     croak 'not connected' unless $CLIENT;
 
-    my $msgid    = $CLIENT->queue($f, \@args);
+    my $msgid    = $CLIENT->queue($task_class, \@args);
     my $deferred = sub { $CLIENT->collect($msgid) };
 
     return $deferred unless wantarray;
@@ -62,12 +66,12 @@ Argon::Simple
 
     connect 'somehost:9999';
 
-    my $deferred = process { shift * 2 } 21;
+    my $deferred = process { $_[0] * 2 } 21;
     if ($deferred->() == 42) {
         print "So long, and thanks for all the fish!\n";
     }
 
-    my ($deferred, $is_finished) = process { shift * 2 } 21;
+    my ($deferred, $is_finished) = process { $_[0] * 2 } 21;
     do { print "." } until $is_finished->();
     print "So long, and thanks for all the fish!\n";
 
@@ -94,6 +98,15 @@ system and is available.
 When called in list context, additionally returns a CODE reference which
 evaluates to true when the task has been completed by the Argon system.
 
+See also L<Coro::ProcessPool/A NOTE ABOUT IMPORTS AND CLOSURES>, which has
+some important information about C<use> and C<require>.
+
+=head2 task 'Task::Class', @args
+
+Similar to process, but passes in the name of a class implementing the methods
+C<new(@args)> and C<run>. The result of C<run> is returned. Note that the class
+must be found on the workers' include paths.
+
 =head1 AUTHOR
 
 Jeff Ober <jeffober@gmail.com>
